# PALPAO server: deformable mirror controller 

[![Build Status][travis]][travislink]  [![Coverage Status][coveralls]][coverallslink]  [![PyPI version][pypiversion]][pypiversionlink]

This is part a component of the Plico framework to control Deformable Mirrors (Alpao, MEMS, PI piezo tip-tilt platform)

See [palpao][palpao] repository for installation and usage

[plico]: https://github.com/lbusoni/plico
[palpao]: https://github.com/lbusoni/palpao
[allied]: https://www.alliedvision.com
[travis]: https://travis-ci.com/lbusoni/palpao_server.svg?branch=master "go to travis"
[travislink]: https://travis-ci.com/lbusoni/palpao_server
[coveralls]: https://coveralls.io/repos/github/lbusoni/palpao_server/badge.svg?branch=master "go to coveralls"
[coverallslink]: https://coveralls.io/github/lbusoni/palpao_server
[pypiversion]: https://badge.fury.io/py/palpao-server.svg
[pypiversionlink]: https://badge.fury.io/py/palpao_server

